==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/iotexplorer/v20190423/models/DeleteLoRaFrequencyRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.iotexplorer.v20190423.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteLoRaFrequencyRequest extends AbstractModel{

    /**
    * 频点唯一ID
    */
    @SerializedName("FreqId")
    @Expose
    private String FreqId;

    /**
     * Get 频点唯一ID 
     * @return FreqId 频点唯一ID
     */
    public String getFreqId() {
        return this.FreqId;
    }

    /**
     * Set 频点唯一ID
     * @param FreqId 频点唯一ID
     */
    public void setFreqId(String FreqId) {
        this.FreqId = FreqId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "FreqId", this.FreqId);

    }
}

==> tencentcloud-sdk-java-3.1.830-sources.jar: com/tencentcloudapi/iotexplorer/v20190423/models/DeleteLoRaFrequencyRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.iotexplorer.v20190423.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteLoRaFrequencyRequest extends AbstractModel{

    /**
    * 频点唯一ID
    */
    @SerializedName("FreqId")
    @Expose
    private String FreqId;

    /**
     * Get 频点唯一ID 
     * @return FreqId 频点唯一ID
     */
    public String getFreqId() {
        return this.FreqId;
    }

    /**
     * Set 频点唯一ID
     * @param FreqId 频点唯一ID
     */
    public void setFreqId(String FreqId) {
        this.FreqId = FreqId;
    }

    public DeleteLoRaFrequencyRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DeleteLoRaFrequencyRequest(DeleteLoRaFrequencyRequest source) {
        if (source.FreqId != null) {
            this.FreqId = new String(source.FreqId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "FreqId", this.FreqId);

    }
}
